@@ -1,6 +1,14 @@
-"""	Command line entry point and metadata """
+"""
+A dice expression parser
 
-__version__ = 1.2
+Author: Sam Clements <sam@borntyping.co.uk>
+
+https://github.com/borntyping/diceroll
+http://pypi.python.org/pypi/diceroll
+"""
+
+__version__ = 2.0
+__all__ = ['roll', 'ParseException']
 
 from parser		import roll
 from pyparsing	import ParseException
